==> cmsmadesimple-1.6.6.tgz: cms/modules/ModuleManager/lang/ext/et_EE.php <==
<?php
$lang['available_updates'] = 'Uuendusteks saadaval moodulid';
$lang['all_modules_up_to_date'] = '&Uuml;htegi uuemait moodulit ei ole saadaval hoidlas';
$lang['error_module_object'] = 'Viga: ei suutnud saada mooduli %s instantsi';
$lang['error_nomatchingmodules'] = 'Viga: ei suutnud leida &uuml;htegi vastavat moodulit hoidlas';
$lang['error_nomodules'] = 'Viga: ei suutnud laadida paigaldatud moodulite nimekirja';
$lang['upgrade_available'] = 'Uuem versioon saadaval (%s), sul on (%s)';
$lang['newversions'] = 'Saadaval uuendused';
$lang['error_depends'] = '&Uuml;ks v&otilde;i mitu s&otilde;ltuvust ei ole paigaldatud. Sa peaksid paigaldama s&otilde;ltuvused k&otilde;igepealt';
$lang['msg_nodependencies'] = 'See fail ei ole loetlenud &uuml;htegi s&otilde;ltuvust';
$lang['dependstxt'] = 'S&otilde;ltuvused';
$lang['use_at_your_own_risk'] = 'Kasutamine omal vastutusel';
$lang['compatibility_disclaimer'] = 'The modules displayed here are contributed by both the CMS Developers, and independant third parties.  We make no guarantees that the modules available here are functional, tested, or compatible with your system.  You are encouraged to read the information found in the help and about links for each module before attempting the installation.';
$lang['notice'] = 'Teade';
$lang['general_notice'] = 'The versions displayed here represent the latest XML files uploaded to your selected repository (usually the CMS %s).  They may or may not represent the latest available versions.';
$lang['incompatible'] = 'Kokkusobimatu';
$lang['prompt_settings'] = 'Seaded';
$lang['prompt_otheroptions'] = 'Teised valikud';
$lang['reset'] = 'Taasta';
$lang['error_permissions'] = '<strong><em>Hoiatus:</em></strong> Ebapiisavad kataloogi&otilde;igused moodulite pigaldamiseks.  Sa v&otilde;id ka kogeda probleeme kui PHP on Turvalises režiimis.  Palun veenduge, et turvaline režiim oleks v&auml;lja l&uuml;litatud ja et failis&uuml;steemi &otilde;igused oleksid piisavad.';
$lang['error_minimumrepository'] = 'Hoidla versioon ei sobi selle mooduli halduriga';
$lang['prompt_reseturl'] = 'Taasta eelseatud vaikimisi URL';
$lang['prompt_resetcache'] = 'Taasta hoidla andmete lokaalne puhver';
$lang['prompt_dl_chunksize'] = 'Downloadi T&uuml;ki Suurus (Kb)';
$lang['text_dl_chunksize'] = 'Maksimaalne andmete suurus, mida korraga serverist t&otilde;mmata (mooduli installeerimisel)';
$lang['error_nofilesize'] = 'Faili suuruse (filesize) parameetrit ei antud';
$lang['error_nofilename'] = 'Faili nime (filename) parameetrit ei antud';
$lang['error_checksum'] = 'Checksum viga.  See viitab ilmselt vigasele failile. Viga v&otilde;is tekkida panipaika &uuml;leslaadimisel v&otilde;i sinu arvutisse kadmisel.';
$lang['cantdownload'] = 'Ei saa alla t&otilde;mmata.';
$lang['download'] = 'T&otilde;mba Alla ja Installeeri';
$lang['error_moduleinstallfailed'] = 'Mooduli installeerimine eba&otilde;nnestus';
$lang['error_connectnomodules'] = 'Kuigi mooduli panipaigaga saavutati &uuml;hendus, ilmnes, et see panipaik ei jaga veel &uuml;htegi moodulit.';
$lang['submit'] = 'Saada';
$lang['text_repository_url'] = 'URL peaks olema vormis http://www.mycmssite.com/path/soap.php?module=ModuleRepository';
$lang['prompt_repository_url'] = 'Mooduli panipaiga URL:';
$lang['availmodules'] = 'Saadaval Moodulid';
$lang['preferences'] = 'Eelistused';
$lang['preferencessaved'] = 'Eelistused salvestatud';
$lang['repositorycount'] = 'Panipaigast leitud Moodulid';
$lang['instcount'] = 'Olemasolevad ja installeeritud Moodulid';
$lang['availablemodules'] = 'K&auml;esolevast panipaigast saadaval olevate moodulite staatus';
$lang['helptxt'] = 'Abi';
$lang['abouttxt'] = 'Info';
$lang['xmltext'] = 'XML Fail';
$lang['nametext'] = 'Mooduli Nimi';
$lang['vertext'] = 'Versioon';
$lang['sizetext'] = 'Suurus (Kilobaitides)';
$lang['statustext'] = 'Staatus/tegevus';
$lang['uptodate'] = 'Installeeritud';
$lang['install'] = 'installeeri';
$lang['newerversion'] = 'Uuem versioon installeeritud';
$lang['onlynewesttext'] = 'N&auml;ita ainult uusimat versiooni';
$lang['upgrade'] = 'Uuenda';
$lang['error_nosoapconnect'] = 'Ei suutnud luua &uuml;hendust SOAP serveriga';
$lang['error_soaperror'] = 'SOAP probleem';
$lang['error_norepositoryurl'] = 'Mooduli panipaiga URL&#039;i pole m&auml;&auml;ratud';
$lang['friendlyname'] = 'Moodulihaldur';
$lang['postinstall'] = 'Installeerimisj&auml;rgne Teade, (nt., M&auml;&auml;ra kindlasti &quot;&quot; &otilde;igused selle mooduli kasutamiseks!)';
$lang['postuninstall'] = 'Moodulihaldur eemaldatud.  Kasutajatel ei ole enam v&otilde;imalik installeerida mooduleid serverites olevatest panipaikadest.  Kohalik installatsioon on siiski v&otilde;imalik.';
$lang['really_uninstall'] = 'Oled kindel, et soovid eemaldada? Sa j&auml;&auml;d ilma paljudest kenadest funkstioonidest.';
$lang['uninstalled'] = 'Moodul eemaldatud.';
$lang['installed'] = 'Mooduli versioon %s installeeritud.';
$lang['upgraded'] = 'Moodul uuendatud versioonile %s.';
$lang['moddescription'] = 'Mooduli panipaiga klient. See moodul v&otilde;imaldab serverites asuvate moodulite eelvaadet ja installeerimist ilma, et oleks tarvis kasutada FTP- v&otilde;i pakkeprogramme. Moodulite XML failid t&otilde;mmatakse alla SOAP abil, nende integratsioon kontrollitakse ning levitatakse automaatselt.';
$lang['error'] = 'Viga!';
$lang['admindescription'] = 'T&ouml;&ouml;riist moodulite t&otilde;mbamiseks ja installeerimiseks serveritest.';
$lang['accessdenied'] = 'Ligip&auml;&auml;s keelatud. Palun kontrolli oma &otilde;igusi.';
$lang['changelog'] = '<ul>
<li>Version 1.0. 10 January 2006. Initial Release.</li>
<li>Version 1.1. July, 2006. Released with the 1.0- beta</li>
<li>Version 1.1.1 August, 2006.  Require 1.0.1 of nuSOAP</li>
<li>Version 1.1.2 September, 2006.  Fixed a mistake that resulted in upgrade not not working at all</li>
<li>Version 1.1.3 September, 2006.
  <ul>
  <li>Bumped minimum CMS Version to 1.0</li>
  <li>Now use 1 request to get the complete list of modules from the repository</li>
  <li>Added some missing lang strings</li>
  <li>Added the ability to reset the local cache of repository information</li>
  <li>Added the ability to restore the repository url to factory defaults</li>
  </ul>
</li>
<li>Version 1.1.4 February, 2007.  Now handles the safe mode check, and disables upgrading or installing modules if the permissions are wrong.</li>
<li>Version 1.1.5 September, 2007. New preference to make only latest module version show. Added nice message after saving preferences</li>
</li>
<li>Version 1.1.6 May, 2008. Now show if available modules are incompatible with the current CMS_VERSION.</li>
</li>
<li>Version 1.2 June, 2008.<br/>
This version should reduce the memory requirements of this module, and trade it off for performance on the server, and mroe requests to the server.
   <ul>
    <li>Bumped Minimum CMS Version to 1.3</li>
    <li>Bumped Minimum repository version to 1.1</li>
    <li>Get rid of all of the session stuff</li>
    <li>Add support for requesting modules beginning with a prefix (usually a single letter)</li>
    <li>Add support for requestion only the newest versions of the modules</li>
   </ul>
</li>
<li>Version 1.2.1 August, 2008.<br/>
Added a warning message to the top of the admin display.
</li>
<li>Version 1.3 May, 2009.<br/>
Added dependency checking.
</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>A client for the ModuleRepository, this module allows previewing, and installing modules from remote sites without the need for ftping, or unzipping archives.  Module XML files are downloaded using SOAP, integrity verified, and then expanded automatically.</p>
<h3>How Do I Use It</h3>
<p>In order to use this module, you will need the &#039;Modify Modules&#039; permission, and you will also need the complete, and full URL to a &#039;Module Repository&#039; installation.  You can specify this url in the &#039;Extensions&#039; --&amp;gt; &#039;Module Manager&#039; --&amp;gt; &#039;Preferences&#039; page.</p><br/>
<p>You can find the interface for this module under the &#039;Extensions&#039; menu.  When you select this module, the &#039;Module Repository&#039; installation will automatically be queried for a list of it&#039;s available xml modules.  This list will be cross referenced with the list of currently installed modules, and a summary page displayed.  From here, you can view the descriptive information, the help, and the about information for a module without physically installing it.  You can also choose to upgrade or install modules.</p>
<h3>Support</h3>
<p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>
<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2006, calguy1000 <a href="mailto:calguy1000@hotmail.com">&amp;lt;calguy1000@hotmail.com&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>';
$lang['utma'] = '156861353.3215545266732019000.1241091787.1254409301.1254415743.144';
$lang['utmz'] = '156861353.1253888638.132.27.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,37360.0.html';
$lang['qca'] = '1240683615-58409973-79915303';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.1.10.1254415743';
?>

==> cmsmadesimple-1.9.4p4.tgz: cms/modules/ModuleManager/lang/ext/et_EE.php <==
<?php
$lang['available_updates'] = 'Uuendusteks saadaval moodulid';
$lang['all_modules_up_to_date'] = '&Uuml;htegi uuemait moodulit ei ole saadaval hoidlas';
$lang['error_module_object'] = 'Viga: ei suutnud saada mooduli %s instantsi';
$lang['error_nomatchingmodules'] = 'Viga: ei suutnud leida &uuml;htegi vastavat moodulit hoidlas';
$lang['error_nomodules'] = 'Viga: ei suutnud laadida paigaldatud moodulite nimekirja';
$lang['upgrade_available'] = 'Uuem versioon saadaval (%s), sul on (%s)';
$lang['newversions'] = 'Saadaval uuendused';
$lang['error_depends'] = '&Uuml;ks v&otilde;i mitu s&otilde;ltuvust ei ole paigaldatud. Sa peaksid paigaldama s&otilde;ltuvused k&otilde;igepealt';
$lang['msg_nodependencies'] = 'See fail ei ole loetlenud &uuml;htegi s&otilde;ltuvust';
$lang['dependstxt'] = 'S&otilde;ltuvused';
$lang['use_at_your_own_risk'] = 'Kasutamine omal vastutusel';
$lang['compatibility_disclaimer'] = 'Siin n&auml;idatud moodulid on panustatud nii CMS arendajate kui ka s&otilde;ltumatute kolmandate osapoolte poolt. Me ei garanteeri, et siin saadaval olevad moodulid on toimivad, testitud v&otilde;i sinu s&uuml;steemiga kokkusobiv. Julgustame sind lugema abi ja info lingist leitavat informatsiooni iga mooduli kohta enne selle paigaldamist.';
$lang['notice'] = 'Teade';
$lang['general_notice'] = 'Siin n&auml;idatud versioonid kujutavad viimast XML faili, mis on &uuml;les laetud sinu valitud panipaika (tavaliselt CMS %s). Need v&otilde;ivad aga ei pruugi kujutada viimast saadaval olevat versiooni.';
$lang['incompatible'] = 'Kokkusobimatu';
$lang['prompt_settings'] = 'Seaded';
$lang['prompt_otheroptions'] = 'Teised valikud';
$lang['reset'] = 'Taasta';
$lang['error_permissions'] = '<strong><em>Hoiatus:</em></strong> Ebapiisavad kataloogi&otilde;igused moodulite pigaldamiseks.  Sa v&otilde;id ka kogeda probleeme kui PHP on Turvalises režiimis.  Palun veenduge, et turvaline režiim oleks v&auml;lja l&uuml;litatud ja et failis&uuml;steemi &otilde;igused oleksid piisavad.';
$lang['error_minimumrepository'] = 'Hoidla versioon ei sobi selle mooduli halduriga';
$lang['prompt_reseturl'] = 'Taasta eelseatud vaikimisi URL';
$lang['prompt_resetcache'] = 'Taasta hoidla andmete lokaalne puhver';
$lang['prompt_dl_chunksize'] = 'Downloadi T&uuml;ki Suurus (Kb)';
$lang['text_dl_chunksize'] = 'Maksimaalne andmete suurus, mida korraga serverist t&otilde;mmata (mooduli installeerimisel)';
$lang['error_nofilesize'] = 'Faili suuruse (filesize) parameetrit ei antud';
$lang['error_nofilename'] = 'Faili nime (filename) parameetrit ei antud';
$lang['error_checksum'] = 'Checksum viga.  See viitab ilmselt vigasele failile. Viga v&otilde;is tekkida panipaika &uuml;leslaadimisel v&otilde;i sinu arvutisse kadmisel.';
$lang['cantdownload'] = 'Ei saa alla t&otilde;mmata.';
$lang['download'] = 'T&otilde;mba Alla ja Installeeri';
$lang['error_moduleinstallfailed'] = 'Mooduli installeerimine eba&otilde;nnestus';
$lang['error_connectnomodules'] = 'Kuigi mooduli panipaigaga saavutati &uuml;hendus, ilmnes, et see panipaik ei jaga veel &uuml;htegi moodulit.';
$lang['submit'] = 'Saada';
$lang['text_repository_url'] = 'URL peaks olema vormis http://www.mycmssite.com/path/soap.php?module=ModuleRepository';
$lang['prompt_repository_url'] = 'Mooduli panipaiga URL:';
$lang['availmodules'] = 'Saadaval Moodulid';
$lang['preferences'] = 'Eelistused';
$lang['preferencessaved'] = 'Eelistused salvestatud';
$lang['repositorycount'] = 'Panipaigast leitud Moodulid';
$lang['instcount'] = 'Olemasolevad ja installeeritud Moodulid';
$lang['availablemodules'] = 'K&auml;esolevast panipaigast saadaval olevate moodulite staatus';
$lang['helptxt'] = 'Abi';
$lang['abouttxt'] = 'Info';
$lang['xmltext'] = 'XML Fail';
$lang['nametext'] = 'Mooduli Nimi';
$lang['vertext'] = 'Versioon';
$lang['sizetext'] = 'Suurus (Kilobaitides)';
$lang['statustext'] = 'Staatus/tegevus';
$lang['uptodate'] = 'Installeeritud';
$lang['install'] = 'installeeri';
$lang['newerversion'] = 'Uuem versioon installeeritud';
$lang['onlynewesttext'] = 'N&auml;ita ainult uusimat versiooni';
$lang['upgrade'] = 'Uuenda';
$lang['error_nosoapconnect'] = 'Ei suutnud luua &uuml;hendust SOAP serveriga';
$lang['error_soaperror'] = 'SOAP probleem';
$lang['error_norepositoryurl'] = 'Mooduli panipaiga URL&#039;i pole m&auml;&auml;ratud';
$lang['friendlyname'] = 'Moodulihaldur';
$lang['postinstall'] = 'Installeerimisj&auml;rgne Teade, (nt., M&auml;&auml;ra kindlasti &quot;&quot; &otilde;igused selle mooduli kasutamiseks!)';
$lang['postuninstall'] = 'Moodulihaldur eemaldatud.  Kasutajatel ei ole enam v&otilde;imalik installeerida mooduleid serverites olevatest panipaikadest.  Kohalik installatsioon on siiski v&otilde;imalik.';
$lang['really_uninstall'] = 'Oled kindel, et soovid eemaldada? Sa j&auml;&auml;d ilma paljudest kenadest funkstioonidest.';
$lang['uninstalled'] = 'Moodul eemaldatud.';
$lang['installed'] = 'Mooduli versioon %s installeeritud.';
$lang['upgraded'] = 'Moodul uuendatud versioonile %s.';
$lang['moddescription'] = 'Mooduli panipaiga klient. See moodul v&otilde;imaldab serverites asuvate moodulite eelvaadet ja installeerimist ilma, et oleks tarvis kasutada FTP- v&otilde;i pakkeprogramme. Moodulite XML failid t&otilde;mmatakse alla SOAP abil, nende integratsioon kontrollitakse ning levitatakse automaatselt.';
$lang['error'] = 'Viga!';
$lang['admindescription'] = 'T&ouml;&ouml;riist moodulite t&otilde;mbamiseks ja installeerimiseks serveritest.';
$lang['accessdenied'] = 'Ligip&auml;&auml;s keelatud. Palun kontrolli oma &otilde;igusi.';
$lang['changelog'] = '<ul>
<li>Version 1.0. 10 January 2006. Initial Release.</li>
<li>Version 1.1. July, 2006. Released with the 1.0- beta</li>
<li>Version 1.1.1 August, 2006.  Require 1.0.1 of nuSOAP</li>
<li>Version 1.1.2 September, 2006.  Fixed a mistake that resulted in upgrade not not working at all</li>
<li>Version 1.1.3 September, 2006.
  <ul>
  <li>Bumped minimum CMS Version to 1.0</li>
  <li>Now use 1 request to get the complete list of modules from the repository</li>
  <li>Added some missing lang strings</li>
  <li>Added the ability to reset the local cache of repository information</li>
  <li>Added the ability to restore the repository url to factory defaults</li>
  </ul>
</li>
<li>Version 1.1.4 February, 2007.  Now handles the safe mode check, and disables upgrading or installing modules if the permissions are wrong.</li>
<li>Version 1.1.5 September, 2007. New preference to make only latest module version show. Added nice message after saving preferences</li>
</li>
<li>Version 1.1.6 May, 2008. Now show if available modules are incompatible with the current CMS_VERSION.</li>
</li>
<li>Version 1.2 June, 2008.<br/>
This version should reduce the memory requirements of this module, and trade it off for performance on the server, and mroe requests to the server.
   <ul>
    <li>Bumped Minimum CMS Version to 1.3</li>
    <li>Bumped Minimum repository version to 1.1</li>
    <li>Get rid of all of the session stuff</li>
    <li>Add support for requesting modules beginning with a prefix (usually a single letter)</li>
    <li>Add support for requestion only the newest versions of the modules</li>
   </ul>
</li>
<li>Version 1.2.1 August, 2008.<br/>
Added a warning message to the top of the admin display.
</li>
<li>Version 1.3 May, 2009.<br/>
Added dependency checking.
</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>A client for the ModuleRepository, this module allows previewing, and installing modules from remote sites without the need for ftping, or unzipping archives.  Module XML files are downloaded using SOAP, integrity verified, and then expanded automatically.</p>
<h3>How Do I Use It</h3>
<p>In order to use this module, you will need the &#039;Modify Modules&#039; permission, and you will also need the complete, and full URL to a &#039;Module Repository&#039; installation.  You can specify this url in the &#039;Extensions&#039; --&amp;gt; &#039;Module Manager&#039; --&amp;gt; &#039;Preferences&#039; page.</p><br/>
<p>You can find the interface for this module under the &#039;Extensions&#039; menu.  When you select this module, the &#039;Module Repository&#039; installation will automatically be queried for a list of it&#039;s available xml modules.  This list will be cross referenced with the list of currently installed modules, and a summary page displayed.  From here, you can view the descriptive information, the help, and the about information for a module without physically installing it.  You can also choose to upgrade or install modules.</p>
<h3>Support</h3>
<p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>
<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2006, calguy1000 <a href="mailto:calguy1000@hotmail.com">&amp;lt;calguy1000@hotmail.com&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>';
$lang['utma'] = '156861353.3215545266732019000.1241091787.1255006508.1255008902.157';
$lang['utmz'] = '156861353.1254469083.145.28.utmccn=(organic)|utmcsr=google|utmctr=cmsms requirements|utmcmd=organic';
$lang['qca'] = '1240683615-58409973-79915303';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.1.10.1255008902';
?>
